==> slideshow_creator-5.x-1.0.tar.gz: slideshow_creator/slideshow_creator.js <==
function SsC_Preload(ss,j) {
var n = SsC[ss][j];
if(n) {
n.image = new Image();
n.image.src = n.src;
n.image.onload = function() { slideshowPreload_2(ss,++j); };
}
}
function SsC_Previous(ss) {
if(!(SsC[ss][--SsC[ss].current])) SsC[ss].current = SsC[ss].total;
SsC_Blend(ss);
}
function SsC_Next(ss) {
if(!(SsC[ss][++SsC[ss].current])) SsC[ss].current = 1;
SsC_Blend(ss);
}
function SsC_ChangeOpac(ss,opacity){
var obj = document.getElementById('slideshow-image:'+ss);
obj.style.opacity=opacity;
obj.style.MozOpacity=opacity;
}
function SsC_Blend(ss){
clearTimeout(SsC[ss].timeout["a1"]);
if (SsC[ss].blend){
for(i=0;i<=100;i+=1)  {
bla=(100-i*2)/101;
if (i>50) {bla=(i*2-100)/101;}
clearTimeout(SsC[ss].timeout[i]);
SsC[ss].timeout[i]=setTimeout("SsC_ChangeOpac('"+ss+"',"+bla+")", i * SsC[ss].blend);
}
clearTimeout(SsC[ss].timeout[1000]);
SsC[ss].timeout[1000]=setTimeout("SsC_Update('"+ss+"')", 50 * SsC[ss].blend);
}
else {SsC_Update(ss);}
}
function SsC_Update(ss) {
var obj = SsC[ss][SsC[ss].current];
var img = document.getElementById('slideshow-image:'+ss);
var link_tit = document.getElementById('slideshow-ltitle:'+ss);
var link_img = document.getElementById('slideshow-link-image:'+ss);
var cur = document.getElementById('slideshow-current:'+ss);
var dec = document.getElementById('slideshow-description:'+ss);
img.src = obj.src;
img.alt = obj.title;
link_img.href = obj.link;
link_img.target = obj.target;
link_tit.innerHTML = obj.title;
link_tit.href = obj.link;
dec.innerHTML = obj.description;
cur.innerHTML = SsC[ss].current;
if (SsC[ss].rotate>0) {SsC[ss].timeout["a1"] = setTimeout("SsC_Next('"+ss+"')",SsC[ss].rotate*1000)};
}
function SsC_Init() {
SsC = Drupal.settings.slideshow;
if (!SsC) return;
for (ss in SsC){
SsC_Preload(ss,1);
obj = document.getElementById('slideshow-previous:'+ss);
obj.onclick = function(){SsC_Previous(this.id.replace(/slideshow-previous:/,"")); return false;};
obj = document.getElementById('slideshow-next:'+ss);
obj.onclick = function(){SsC_Next(this.id.replace(/slideshow-next:/,"")); return false;};
obj = document.getElementById('slideshow-image:'+ss);
obj.onmouseover = function() {ss=this.id.replace(/slideshow-image:/,"");clearTimeout(SsC[ss].timeout["a1"]);};
obj.onmouseout = function() {ss=this.id.replace(/slideshow-image:/,"");SsC[ss].timeout["a1"] = setTimeout("SsC_Next('"+ss+"')",SsC[ss].rotate*1000)};
if (SsC[ss].blend>SsC[ss].rotate){SsC[ss].blend=SsC[ss].rotate;};
if (SsC[ss].rotate>0) {SsC[ss].timeout["a1"] = setTimeout("SsC_Next('"+ss+"')",SsC[ss].rotate*1000)};
}
}
$(document).ready(function() {
SsC_Init();
})

==> slideshow_creator-5.x-1.12.tar.gz: slideshow_creator/slideshow_creator.js <==
function SsC_Preload(ss,j) {
var n = SsC[ss][j];
if(n) {
n.image = new Image();
n.image.src = n.src;
n.image.onload = function() { SsC_Preload(ss,++j); };
}
}
function SsC_Previous(ss) {
if(!(SsC[ss][--SsC[ss].current])) SsC[ss].current = SsC[ss].total;
SsC_Blend(ss);
}
function SsC_Next(ss) {
if(!(SsC[ss][++SsC[ss].current])) SsC[ss].current = 1;
SsC_Blend(ss);
}
function SsC_ChangeOpac(ss,opacity){
var obj = document.getElementById('slideshow-image:'+ss);
obj.style.opacity=opacity;
obj.style.MozOpacity=opacity;
}
function SsC_Blend(ss){
clearTimeout(SsC[ss].timeout["a1"]);
if (SsC[ss].blend){
for(i=0;i<=100;i+=1)  {
bla=(100-i*2)/101;
if (i>50) {bla=(i*2-100)/101;}
clearTimeout(SsC[ss].timeout[i]);
SsC[ss].timeout[i]=setTimeout("SsC_ChangeOpac('"+ss+"',"+bla+")", i * SsC[ss].blend);
}
clearTimeout(SsC[ss].timeout[1000]);
SsC[ss].timeout[1000]=setTimeout("SsC_Update('"+ss+"')", 50 * SsC[ss].blend);
}
else {SsC_Update(ss);}
}
function SsC_Update(ss) {
var obj = SsC[ss][SsC[ss].current];
var img = document.getElementById('slideshow-image:'+ss);
var link_tit = document.getElementById('slideshow-ltitle:'+ss);
var link_img = document.getElementById('slideshow-link-image:'+ss);
var cur = document.getElementById('slideshow-current:'+ss);
var dec = document.getElementById('slideshow-description:'+ss);
img.src = obj.src;
img.alt = obj.title;
link_img.href = obj.link;
link_img.target = obj.target;
link_tit.innerHTML = obj.title;
link_tit.href = obj.link;
dec.innerHTML = obj.description;
cur.innerHTML = SsC[ss].current;
if (SsC[ss].rotate>0) {SsC[ss].timeout["a1"] = setTimeout("SsC_Next('"+ss+"')",SsC[ss].rotate*1000)};
}
function SsC_Init() {
SsC = Drupal.settings.slideshow;
if (!SsC) return;
for (ss in SsC){
SsC_Preload(ss,1);
obj = document.getElementById('slideshow-previous:'+ss);
obj.onclick = function(){SsC_Previous(this.id.replace(/slideshow-previous:/,"")); return false;};
obj = document.getElementById('slideshow-next:'+ss);
obj.onclick = function(){SsC_Next(this.id.replace(/slideshow-next:/,"")); return false;};
obj = document.getElementById('slideshow-image:'+ss);
obj.onmouseover = function() {ss=this.id.replace(/slideshow-image:/,"");clearTimeout(SsC[ss].timeout["a1"]);};
obj.onmouseout = function() {ss=this.id.replace(/slideshow-image:/,"");SsC[ss].timeout["a1"] = setTimeout("SsC_Next('"+ss+"')",SsC[ss].rotate*1000)};
if (SsC[ss].blend>SsC[ss].rotate){SsC[ss].blend=SsC[ss].rotate;};
if (SsC[ss].rotate>0) {SsC[ss].timeout["a1"] = setTimeout("SsC_Next('"+ss+"')",SsC[ss].rotate*1000)};
}
}
$(document).ready(function() {
SsC_Init();
})
